use std::ops::Index;

use super::header::Header;

#[derive(Debug, Clone)]
pub struct Body(Vec<u8>);

impl Body {
    pub fn body_type(&self) -> u8 {
        self.0[0]
    }

    pub fn raw(&self) -> &[u8] {
        &self.0
    }

    pub fn len(&self) -> usize {
        self.0.len()
    }
}

impl From<&[u8]> for Body {
    fn from(value: &[u8]) -> Self {
        Self(
            value[(Header::HEADER_LENGTH as usize)..value.len() - 1]
                .iter()
                .cloned()
                .collect::<Vec<u8>>()
                .try_into()
                .unwrap(),
        )
    }
}

impl Index<usize> for Body {
    type Output = u8;

    fn index(&self, index: usize) -> &Self::Output {
        &self.0[index]
    }
}
