use super::{body::Body, header::Header, Command, MessageType};

pub struct CommandRequest {
    command: Command,
}

impl CommandRequest {
    fn checksum(data: &[u8]) -> u8 {
        ((!data.iter().map(|&b| b as u16).sum::<u16>() + 1) & 0xFF) as u8
    }

    pub fn new(
        device_protocol_version: u8,
        device_type: u8,
        message_type: MessageType,
        body: Body,
    ) -> Self {
        Self {
            command: Command {
                header: Header::new(
                    body.len() as u8,
                    device_type,
                    device_protocol_version,
                    message_type,
                ),
                body,
            },
        }
    }

    pub fn serialize(&self, body: &[u8]) -> Vec<u8> {
        let mut stream = Vec::new();

        stream.extend_from_slice(self.command.header.raw());
        stream.extend_from_slice(self.command.body.raw());
        stream.push(Self::checksum(&stream[1..]));

        stream
    }
}

pub struct CommandQuerySubtype {
    command: CommandRequest,
}

impl CommandQuerySubtype {
    pub fn new(device_type: u8) -> Self {
        Self {
            command: CommandRequest::new(
                0,
                device_type,
                MessageType::QuerySubtype,
                Body::from([0x00; 18].as_slice()),
            ),
        }
    }
}

pub struct CommandQueryCustom {
    command: CommandRequest,
}

impl CommandQueryCustom {
    pub fn new(device_type: u8, message_type: MessageType, body: Body) -> Self {
        Self {
            command: CommandRequest::new(0, device_type, message_type, body),
        }
    }
}
